@@ -310,7 +310,7 @@ pushd ${_buildd_static}
                        ${_DISABLE_SHARED} "${_PROFILE_TASK[@]}"
 popd
 
-if [[ ${target_platform} == linux-ppc64le ]]; then
+if [[ "${CI}" == "travis" ]]; then
   # Travis has issues with long logs
   make -j${CPU_COUNT} -C ${_buildd_static} \
        EXTRA_CFLAGS="${EXTRA_CFLAGS}" \
@@ -325,7 +325,7 @@ if rg "Failed to build these modules" make-static.log; then
   exit 1
 fi
 
-if [[ ${target_platform} == linux-ppc64le ]]; then
+if [[ "${CI}" == "travis" ]]; then
   # Travis has issues with long logs
   make -j${CPU_COUNT} -C ${_buildd_shared} \
           EXTRA_CFLAGS="${EXTRA_CFLAGS}" 2>&1 >make-shared.log
@@ -390,6 +390,8 @@ if [[ -f ${PREFIX}/bin/python${VER}m ]]; then
 fi
 ln -s ${PREFIX}/bin/python${VER} ${PREFIX}/bin/python
 ln -s ${PREFIX}/bin/pydoc${VER} ${PREFIX}/bin/pydoc
+# Workaround for https://github.com/conda/conda/issues/10969
+ln -s ${PREFIX}/bin/python3.10 ${PREFIX}/bin/python3.1
 
 # Remove test data to save space
 # Though keep `support` as some things use that.
@@ -448,8 +450,11 @@ pushd "${PREFIX}"/lib/python${VER}
   # Append the conda-forge zoneinfo to the end
   sed -i.bak "s@zoneinfo'@zoneinfo:$PREFIX/share/tzinfo'@g" sysconfigfile
   # Remove osx sysroot as it depends on the build machine
-  sed -i.bak "s@-isysroot @@g" sysconfigfile
-  sed -i.bak "s@$CONDA_BUILD_SYSROOT @@g" sysconfigfile
+  # be sure CONDA_BUILD_SYSROOT has value, as other we will remove here instead spaces
+  if [[ "${target_platform}" == osx-* ]] && [[ -n ${CONDA_BUILD_SYSROOT} ]]; then
+    sed -i.bak "s@-isysroot @@g" sysconfigfile
+    sed -i.bak "s@$CONDA_BUILD_SYSROOT @@g" sysconfigfile
+  fi
   # Remove unfilled config option
   sed -i.bak "s/@SGI_ABI@//g" sysconfigfile
   sed -i.bak "s@$BUILD_PREFIX/bin/${HOST}-llvm-ar@${HOST}-ar@g" sysconfigfile
@@ -469,8 +474,8 @@ pushd "${PREFIX}"/lib/python${VER}
     sed -i.bak "s@-pthread@-pthread -B $PREFIX/compiler_compat@g" sysconfigfile
   fi
   # Don't set -march and -mtune for system gcc
-  sed -i.bak "s@-march=[a-z0-9]*@@g" sysconfigfile
-  sed -i.bak "s@-mtune=[a-z0-9]*@@g" sysconfigfile
+  sed -i.bak "s@-march=[^( |\\\"|\\\')]*@@g" sysconfigfile
+  sed -i.bak "s@-mtune=[^( |\\\"|\\\')]*@@g" sysconfigfile
   # Remove these flags that older compilers and linkers may not know
   for flag in "-fstack-protector-strong" "-ffunction-sections" "-pipe" "-fno-plt" \
             "-ftree-vectorize" "-Wl,--sort-common" "-Wl,--as-needed" "-Wl,-z,relro" \
@@ -505,3 +510,7 @@ rm ${PREFIX}/lib/libpython${VER}.a
 if [[ "$target_platform" == linux-* ]]; then
   rm ${PREFIX}/include/uuid.h
 fi
+
+# Workaround for old conda versions which fail to install noarch packages for Python 3.10+
+# https://github.com/conda/conda/issues/10969
+ln -s "${PREFIX}/lib/python3.10" "${PREFIX}/lib/python3.1"
